@@ -1,6 +1,6 @@
 ## Domain Registry Interface, local global cache
 ##
-## Copyright (c) 2005,2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,8 +66,7 @@ See the LICENSE file that comes with this distribution for more details.
 ####################################################################################################
 sub new
 {
- my $c=shift;
- my ($ttl)=@_;
+ my ($c,$ttl)=@_;
 
  my $self={
            ttl  => $ttl, ## if negative, never use cache
@@ -115,6 +114,7 @@ sub set_result_from_cache
  Net::DRI::Exception::err_insufficient_parameters() unless Net::DRI::Util::all_valid($type,$key);
  return unless exists $self->{data}->{$type};
  $self->{data}->{$type}->{$key}->{result_from_cache}=1;
+ return;
 }
 
 sub get
@@ -160,12 +160,14 @@ sub delete_expired
    delete $c->{$type}->{$key} if ($c2->{_until} > 0 && ($now > $c2->{_until}));
   }
  }
+ return;
 }
 
-sub delete
+sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my $self=shift;
  $self->{data}={};
+ return;
 }
 
 ####################################################################################################
