@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol superclass
 ##
-## Copyright (c) 2005-2011,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2011,2013-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -62,7 +62,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2011,2013-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -144,7 +144,7 @@ sub _load
 
  my %skip = map { substr($_,1) => 1 } grep { /^-/ } @classes;
 
- my (%c,%done,@done);
+ my (%done, @done, @commands);
  foreach my $class (@classes)
  {
   next if exists $done{$class} || $class=~m/^-/ || exists $skip{$class};
@@ -153,7 +153,8 @@ sub _load
   Net::DRI::Exception::method_not_implemented('register_commands',$class) unless $class->can('register_commands');
   my $rh=$class->register_commands($version);
   $self->{commands_by_class}->{$class}=$rh;
-  Net::DRI::Util::hash_merge(\%c,$rh); ## { object type => { action type => [ build action, parse action ]+ } }
+  push @commands, $rh;
+
   if ($class->can('capabilities_add'))
   {
    my @a=$class->capabilities_add();
@@ -171,6 +172,11 @@ sub _load
  }
 
  $self->{loaded_modules}=\@done;
+ my %c;
+ foreach my $rh (@commands)
+ {
+  Net::DRI::Util::hash_merge(\%c, $rh); ## { object type => { action type => [ build action, parse action ]+ } }
+ }
  $self->commands(\%c);
  return;
 }
