@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DAS Protocol for .NL
 ##
-## Copyright (c) 2009-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009-2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,7 +79,7 @@ sub new
 sub _load
 {
  my ($self,$rp)=@_;
- $self->SUPER::_load('Net::DRI::Protocol::DAS::SIDN::Domain');
+ return $self->SUPER::_load('Net::DRI::Protocol::DAS::SIDN::Domain');
 }
 
 sub transport_default
