@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Contact commands (RFC5733)
 ##
-## Copyright (c) 2005-2010,2012-2013,2015 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2010,2012-2013,2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2010,2012-2013,2015 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2010,2012-2013,2015,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@ sub register_commands
            transfer_request => [ \&transfer_request, \&transfer_parse ],
            transfer_cancel  => [ \&transfer_cancel,\&transfer_parse ],
            transfer_answer  => [ \&transfer_answer,\&transfer_parse ],
-	   update => [ \&update ],
+           update => [ \&update ],
            review_complete => [ undef, \&pandata_parse ],
          );
 
@@ -98,7 +98,7 @@ sub build_command
  }
 
  my $tcommand=(ref($command))? $command->[0] : $command;
- $msg->command([$command,'contact:'.$tcommand,sprintf('xmlns:contact="%s" xsi:schemaLocation="%s %s"',$msg->nsattrs('contact'))]);
+ $msg->command([$command,'contact:'.$tcommand, $msg->nsattrs('contact')]);
 
  my @d=map { ['contact:id',$_] } @c;
 
@@ -419,7 +419,7 @@ sub pandata_parse
    $rinfo->{contact}->{$oname}->{result}=Net::DRI::Util::xml_parse_boolean($c->getAttribute('paResult'));
   } elsif ($name eq 'paTRID')
   {
-   my $ns=$mes->ns('_main');
+   my $ns=$mes->ns('epp');
    my $tmp=Net::DRI::Util::xml_child_content($c,$ns,'clTRID');
    $rinfo->{contact}->{$oname}->{trid}=$tmp if defined $tmp;
    $rinfo->{contact}->{$oname}->{svtrid}=Net::DRI::Util::xml_child_content($c,$ns,'svTRID');
