@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) Contact EPP extension commands
 ##
-## Copyright (c) 2008,2009,2012,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2012,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2012,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2012,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,12 +76,6 @@ sub register_commands
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:frnic="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('frnic')));
-}
-
 sub create
 {
  my ($epp,$contact)=@_;
@@ -151,7 +145,7 @@ sub create
 
  push @n,build_q_reachable($qual);
 
- my $eid=build_command_extension($mes,$epp,'frnic:ext');
+ my $eid=$mes->command_extension_register('frnic', 'ext');
  $mes->command_extension($eid,['frnic:create',['frnic:contact',@n]]);
  return;
 }
@@ -236,7 +230,7 @@ sub update
  push @n,['frnic:add',@add] if @add;
  push @n,['frnic:rem',@del] if @del;
 
- my $eid=build_command_extension($mes,$epp,'frnic:ext');
+ my $eid=$mes->command_extension_register('frnic', 'ext');
  $mes->command_extension($eid,['frnic:update',['frnic:contact',@n]]);
  return;
 }
