@@ -1,6 +1,6 @@
 ## Domain Registry Interface, ARNES (.SI) EPP extensions
 ##
-## Copyright (c) 2008,2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,7 +66,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({ dnssi => ['http://www.arnes.si/xml/epp/dnssi-1.2','dnssi-1.2.xsd'] });
+ $self->ns({ dnssi => 'http://www.arnes.si/xml/epp/dnssi-1.2' });
  $self->factories('contact',sub { return Net::DRI::Data::Contact::ARNES->new(@_); });
  $self->capabilities('contact_update','disclose',['add','del']);
  $self->factories('status',sub { return Net::DRI::Protocol::EPP::Extensions::ARNES::Status->new(); });
