@@ -1,7 +1,7 @@
 ## Domain Registry Interface, ASIA CED extension
 ##
 ## Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##           (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>
-          (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>
+          (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -99,12 +99,11 @@ sub auto_cedother
 sub user_create
 {
  my ($epp,$contact,$rd)=@_;
- my $mes=$epp->message();
- my @ceddata;
 
  return unless Net::DRI::Util::isa_contact($contact, 'Net::DRI::Data::Contact::ASIA');
 
  $contact = auto_cedother($contact);
+ my @ceddata;
  push(@ceddata, ['asia:ccLocality', $contact->cedcc()])         if defined $contact->cedcc()        && length $contact->cedcc();
  push(@ceddata, ['asia:localitySp', $contact->cedsp()])         if defined $contact->cedsp()        && length $contact->cedsp();
  push(@ceddata, ['asia:localityCity', $contact->cedcity()])     if defined $contact->cedcity()      && length $contact->cedcity();
@@ -114,9 +113,10 @@ sub user_create
  push(@ceddata, ['asia:otherLEType', $contact->cedothertype()]) if defined $contact->cedothertype() && length $contact->cedothertype();
  push(@ceddata, ['asia:otherIdentForm', $contact->cedoiform()]) if defined $contact->cedoiform()    && length $contact->cedoiform();
 
- return unless (@ceddata);
+ return unless @ceddata;
 
- my $eid=$mes->command_extension_register('asia:create',sprintf('xmlns:asia="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('asia')));
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('asia', 'create');
  $mes->command_extension($eid,['asia:cedData', @ceddata]);
  return;
 }
@@ -124,11 +124,10 @@ sub user_create
 sub user_update
 {
  my ($epp,$contact,$todo)=@_;
- my $mes=$epp->message();
  my $newc=$todo->set('info');
- my @ceddata;
 
  $contact = auto_cedother($contact);
+ my @ceddata;
  push(@ceddata, ['asia:ccLocality', $contact->cedcc()])         if defined $contact->cedcc();
  push(@ceddata, ['asia:localitySp', $contact->cedsp()])         if defined $contact->cedsp();
  push(@ceddata, ['asia:localityCity', $contact->cedcity()])     if defined $contact->cedcity();
@@ -138,9 +137,10 @@ sub user_update
  push(@ceddata, ['asia:otherLEType', $contact->cedothertype()]) if defined $contact->cedothertype();
  push(@ceddata, ['asia:otherIdentForm', $contact->cedoiform()]) if defined $contact->cedoiform();
 
- return unless (@ceddata);
+ return unless @ceddata;
 
- my $eid=$mes->command_extension_register('asia:update',sprintf('xmlns:asia="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('asia')));
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('asia', 'update');
  $mes->command_extension($eid,['asia:chg', ['asia:cedData', @ceddata]]);
  return;
 }
