@@ -1,6 +1,7 @@
 ## Domain Registry Interface, .AU Domain EPP extension commands
 ##
 ## Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
+## Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,6 +49,7 @@ Rony Meyer, E<lt>perl@spot-light.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
+Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,12 +76,6 @@ sub register_commands
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:auext="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('auext')));
-}
-
 sub create
 {
  my ($epp,$domain,$rd)=@_;
@@ -109,7 +105,7 @@ sub create
  }
  push @n,['auext:policyReason',$rd->{eligibility}->{policyReason}];
 
- my $eid=build_command_extension($mes,$epp,'auext:extensionAU');
+ my $eid=$mes->command_extension_register('auext', 'extensionAU');
 
  my @nn;
  push @nn, ['auext:create',@n];
