@@ -1,4 +1,4 @@
-## Allocation Token Mapping for EPP (draft-ietf-regext-allocation-token-06)
+## Allocation Token Mapping for EPP ((RFC8495)
 ##
 ## Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
@@ -45,7 +45,7 @@ sub setup
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/html/draft-ietf-regext-allocation-token-07'; }
+sub implements { return 'https://tools.ietf.org/html/rfc8495'; }
 
 ####################################################################################################
 
@@ -97,7 +97,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::AllocationToken - EPP Allocation Token mapping (draft-ietf-regext-allocation-token-06) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::AllocationToken - EPP Allocation Token mapping (RFC8495) for Net::DRI
 
 =head1 DESCRIPTION
 
