@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Defensive Registration EPP extension commands
 ##
-## Copyright (c) 2006-2010,2013-2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2010,2013-2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010,2013-2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2010,2013-2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -93,7 +93,7 @@ sub build_command
 
  Net::DRI::Exception->die(1,'protocol/EPP',2,'Defensive registration id needed') unless @id;
 
- $mes->command([$command,'defreg:'.$command,sprintf('xmlns:defreg="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('defreg'))]);
+ $mes->command([$command,'defreg:'.$command, $mes->nsattrs('defreg')]);
  return map { ['defreg:id',$_] } @id;
 }
 
