@@ -1,6 +1,6 @@
 ## Domain Registry Interface, CIRA EPP Domain extensions
 ##
-## Copyright (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -36,12 +36,6 @@ sub register_commands
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:cira="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('cira')));
-}
-
 sub info_parse
 {
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
@@ -83,7 +77,7 @@ sub create
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
+
  return unless Net::DRI::Util::has_contact($rd);
 
  my @n;
@@ -102,7 +96,8 @@ sub transfer_request
   push @n,map { ['cira:contact',{type=>'tech'},$_->srid()] } @c;
  }
 
- my $eid=build_command_extension($mes,$epp,'cira:ciraTransfer');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('cira','ciraTransfer');
  $mes->command_extension($eid,['cira:ciraChg',@n]);
  return;
 }
@@ -140,7 +135,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
