@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .CO.ZA Domain EPP extension commands
 ## From http://registry.coza.net.za/doku.php?id=eppdomainextension
 ##
-## Copyright (c) 2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2011,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -37,7 +37,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'cozadomain' => [ 'http://co.za/epp/extensions/cozadomain-1-0','coza-domain-1.0.xsd' ] });
+ $po->ns({ 'cozadomain' => 'http://co.za/epp/extensions/cozadomain-1-0' });
  return;
 }
 
@@ -141,7 +141,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2011,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
