@@ -1,6 +1,7 @@
 ## Domain Registry Interface, CZ domain transactions extension
 ##
 ## Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+##               2018 Patrick Mevzek <netdri@dotandco.com>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -55,6 +56,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+              2018 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -99,8 +101,7 @@ sub build_command
 	}
 
 	my $tcommand = (ref($command)) ? $command->[0] : $command;
-	$msg->command([$command, 'domain:' . $tcommand,
-		sprintf('xmlns:domain="%s" xsi:schemaLocation="%s %s"',$msg->nsattrs('domain'))]);
+	$msg->command([$command, 'domain:' . $tcommand, $msg->nsattrs('domain')]);
 	my @d = map { ['domain:name', $_, $domainattr] } @dom;
 	return @d;
 }
