@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .CZ EPP NSSET extension commands
 ##
 ## Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##           (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>
+##           (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -18,6 +18,7 @@ package Net::DRI::Protocol::EPP::Extensions::CZ::NSSET;
 
 use strict;
 use warnings;
+use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
@@ -54,7 +55,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>
+          (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -88,11 +89,13 @@ sub register_commands
 	return { 'nsset' => \%tmp1 };
 }
 
-sub ns
+sub setup
 {
-	my ($mes) = @_;
-        my $ns=$mes->ns('nsset');
-        return defined($ns)? $ns : 'http://www.nic.cz/xml/epp/nsset-1.2';
+ my ($class,$po,$version)=@_;
+
+ state $ns = { 'nsset' => 'http://www.nic.cz/xml/epp/nsset-1.2' };
+ $po->ns($ns);
+ return;
 }
 
 sub build_command
@@ -117,10 +120,7 @@ sub build_command
 	Net::DRI::Exception->die(1, 'protocol/EPP', 2, 'NSgroup name needed')
 		unless @gn;
 
-        my @ns=$msg->nsattrs('nsset');
-        @ns=qw(http://www.nic.cz/xml/epp/nsset-1.2 http://www.nic.cz/xml/epp/nsset-1.2 nsset-1.2.xsd) unless @ns;
-	$msg->command([$command, 'nsset:' . $tcommand,
-		sprintf('xmlns:nsset="%s" xsi:schemaLocation="%s %s"',@ns)]);
+	$msg->command([$command, 'nsset:' . $tcommand, $msg->nsattrs('nsset')]);
 
 	return map { ['nsset:id', $_] } @gn;
 }
@@ -205,11 +205,10 @@ sub check_parse
 	my $mes = $po->message();
 	return unless $mes->is_success();
 
-	my $ns = ns($mes);
-	my $chkdata = $mes->get_response($ns,'chkData');
+	my $chkdata = $mes->get_response('nsset', 'chkData');
 	return unless $chkdata;
 
-	foreach my $cd ($chkdata->getElementsByTagNameNS($ns, 'cd'))
+	foreach my $cd ($chkdata->getElementsByTagNameNS($mes->ns('nsset'), 'cd'))
 	{
 		my $c = $cd->getFirstChild();
 		my $nsset;
@@ -248,7 +247,7 @@ sub info_parse
 	my $mes = $po->message();
 	return unless $mes->is_success();
 
-	my $infdata = $mes->get_response(ns($mes),'infData');
+	my $infdata = $mes->get_response('nsset','infData');
 	return unless $infdata;
 
 	my $ns = Net::DRI::Data::Hosts->new();
@@ -301,12 +300,12 @@ sub info_parse
 			my $hostname;
 			my @v4;
 			my @v6;
-			foreach my $xname ($c->getElementsByTagNameNS(ns($mes),
+			foreach my $xname ($c->getElementsByTagNameNS($mes->ns('nsset'),
 				'name'))
 			{
 				$hostname = $xname->getFirstChild()->getData();
 			}
-			foreach my $xaddr ($c->getElementsByTagNameNS(ns($mes),
+			foreach my $xaddr ($c->getElementsByTagNameNS($mes->ns('nsset'),
 				'addr'))
 			{
 				my $xa = $xaddr->getFirstChild()->getData();
