@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic Release EPP extension
 ## (http://labs.centralnic.com/epp/ext/release.php)
 ##
-## Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -83,7 +83,7 @@ sub release
 
  Net::DRI::Exception::usererr_invalid_parameters('release operation needs a clID') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{clID}) && defined($rd->{clID}) && $rd->{clID});
 
- $mes->command([['transfer',{'op'=>'release'}],'domain:transfer',sprintf('xmlns:domain="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('domain'))]);
+ $mes->command([['transfer',{'op'=>'release'}],'domain:transfer', $mes->nsattrs('domain')]);
  my @d=(['domain:name',$domain],['domain:clID',$rd->{clID}]);
  $mes->command_body(\@d);
  return;
