@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic DNS TTL EPP extension
 ## (http://labs.centralnic.com/epp/ext/ttl.php)
 ##
-## Copyright (c) 2007,2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -98,11 +98,11 @@ sub info_parse
 sub create
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  return unless (exists($rd->{ttl}) && ((ref($rd->{ttl}) && Net::DRI::Util::is_class($rd->{ttl},'DateTime::Duration')) || $rd->{ttl}=~m/^\d+$/));
 
- my $eid=$mes->command_extension_register('ttl:create',sprintf('xmlns:ttl="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ttl')));
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ttl', 'create');
  my @n=(['ttl:secs',ref($rd->{ttl})? $rd->{ttl}->in_units('seconds') : $rd->{ttl}]);
  $mes->command_extension($eid,\@n);
  return;
@@ -111,12 +111,12 @@ sub create
 sub update
 {
  my ($epp,$domain,$todo)=@_;
- my $mes=$epp->message();
 
  my $toset=$todo->set('ttl');
  return unless (defined $toset && ((ref $toset && Net::DRI::Util::is_class($toset,'DateTime::Duration')) || $toset=~m/^\d+$/));
 
- my $eid=$mes->command_extension_register('ttl:update',sprintf('xmlns:ttl="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ttl')));
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ttl', 'update');
  my @n=(['ttl:secs',ref($toset)? $toset->in_units('seconds') : $toset]);
  $mes->command_extension($eid,\@n);
  return;
