@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP E.164 Number Mapping (RFC4114)
 ##
-## Copyright (c) 2005-2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2009,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2009,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -78,7 +78,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'e164' => [ 'urn:ietf:params:xml:ns:e164epp-1.0','e164epp-1.0.xsd' ] });
+ $po->ns({ 'e164' => 'urn:ietf:params:xml:ns:e164epp-1.0' });
  return;
 }
 
