@@ -1,6 +1,6 @@
 ## Domain Registry Interface, FCCN (.PT) Contact EPP extension commands
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,7 +64,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=( 
+ my %tmp=(
           create => [ \&create, undef ],
           update => [ \&update, undef ],
           info   => [ undef, \&info_parse ],
@@ -75,12 +75,6 @@ sub register_commands
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:ptcontact="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ptcontact')));
-}
-
 sub create
 {
  my ($epp,$contact)=@_;
@@ -91,7 +85,7 @@ sub create
  push @n,['ptcontact:identification',$contact->identification()->{value}];
  push @n,['ptcontact:mobile',$contact->mobile()] if $contact->mobile();
 
- my $eid=build_command_extension($mes,$epp,'ptcontact:create');
+ my $eid=$mes->command_extension_register('ptcontact', 'create');
  $mes->command_extension($eid,\@n);
  return;
 }
@@ -99,7 +93,6 @@ sub create
 sub update
 {
  my ($epp,$contact,$todo)=@_;
- my $mes=$epp->message();
 
  my @n;
  my $auth=$contact->auth();
@@ -113,7 +106,8 @@ sub update
   push @n,['ptcontact:mobile',$newc->mobile()] if $newc->mobile();
  }
 
- my $eid=build_command_extension($mes,$epp,'ptcontact:update');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptcontact', 'update');
  $mes->command_extension($eid,\@n);
  return;
 }
