@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .PT Domain EPP extension commands
 ##
-## Copyright (c) 2008,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,7 @@ sub register_commands
           renew  => [ \&renew ],
           renounce => [ \&renounce ],
           delete => [ \&delete ],
-	  transfer_request => [ \&transfer_request ],
+          transfer_request => [ \&transfer_request ],
          );
 
  return { 'domain' => \%tmp };
@@ -81,16 +81,9 @@ sub register_commands
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:ptdomain="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ptdomain')));
-}
-
 sub create
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('Registrant contact required for .PT domain name creation') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->has_type('registrant'));
  Net::DRI::Exception::usererr_insufficient_parameters('Tech contact required for .PT domain name creation') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->has_type('tech'));
@@ -104,11 +97,12 @@ sub create
   Net::DRI::Exception::usererr_invalid_parameters($d.' must be either 0 or 1 for .PT domain name creation') unless ($rd->{$d}==0 || $rd->{$d}==1);
  }
 
+ my $mes=$epp->message();
  my @n;
  push @n,['ptdomain:legitimacy',{type => $rd->{legitimacy}}];
  push @n,['ptdomain:registration_basis',{type => $rd->{registration_basis}}];
  push @n,['ptdomain:autoRenew',$rd->{auto_renew}];
- my $eid=build_command_extension($mes,$epp,'ptdomain:create');
+ my $eid=$mes->command_extension_register('ptdomain', 'create');
  $mes->command_extension($eid,\@n);
  return;
 }
@@ -144,11 +138,11 @@ sub add_roid
 sub info
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name info') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:info');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'info');
  my @n=add_roid($rd->{roid});
  $mes->command_extension($eid,\@n);
  return;
@@ -187,11 +181,11 @@ sub info_parse
 sub update
 {
  my ($epp,$domain,$toc,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name update') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:update');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'update');
  my @n=add_roid($rd->{roid});
  $mes->command_extension($eid,\@n);
  return;
@@ -200,7 +194,6 @@ sub update
 sub renew
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name renew') unless (Net::DRI::Util::has_key($rd,'roid'));
 
@@ -213,7 +206,8 @@ sub renew
  }
  Net::DRI::Exception::usererr_invalid_parameters('only one of duration, auto_renew and not_renew attributes can be set for .PT domain name renew') if $c > 1;
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:renew');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'renew');
  my @n=add_roid($rd->{roid});
  push @n,['ptdomain:autoRenew',$rd->{auto_renew}] if Net::DRI::Util::has_key($rd,'auto_renew');
  push @n,['ptdomain:notRenew',$rd->{not_renew}] if Net::DRI::Util::has_key($rd,'not_renew');
@@ -224,11 +218,11 @@ sub renew
 sub renounce
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name renounce') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:renounce');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'renounce');
  my @n=(['ptdomain:name',$domain]);
  push @n,add_roid($rd->{roid});
  push @n,['ptdomain:clTRID',$mes->cltrid()];
@@ -239,11 +233,11 @@ sub renounce
 sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name delete') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:delete');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'delete');
  my @n=add_roid($rd->{roid});
  $mes->command_extension($eid,\@n);
  return;
@@ -252,11 +246,11 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('you have to specify authinfo for .PT domain transfer (mapped to transferKey)') unless Net::DRI::Util::has_auth($rd);
 
- my $eid=build_command_extension($mes,$epp,'ptdomain:transfer');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('ptdomain', 'transfer');
  $mes->command_extension($eid,['ptdomain:transferKey',$rd->{"auth"}->{"pw"}]);
  return;
 }
