@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .LU Domain EPP extension commands
 ##
-## Copyright (c) 2007,2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -89,12 +89,6 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:dnslu="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('dnslu')));
-}
-
 ####################################################################################################
 
 sub info_parse
@@ -165,7 +159,7 @@ sub create
  return unless Net::DRI::Util::has_key($rd,'status');
  my @n=map { ['dnslu:status',{ s => $_ }] } (Net::DRI::Util::isa_statuslist($rd->{status})? $rd->{status}->list_status() : @{$rd->{status}});
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:create',['dnslu:domain',@n]]);
  return;
 }
@@ -185,7 +179,7 @@ sub update
  push @n,['dnslu:rem',@del] if @del;
  return unless @n;
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:update',['dnslu:domain',@n]]);
  return;
 }
@@ -207,7 +201,7 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
   push @n,['dnslu:delDate',$rd->{delDate}->set_time_zone('UTC')->strftime('%Y-%m-%dT%TZ')];
  }
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:delete',['dnslu:domain',@n]]);
  return;
 }
@@ -228,7 +222,7 @@ sub restore
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:restore',['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -256,7 +250,7 @@ sub transfer_request
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:transfer',['dnslu:domain',build_transfer_trade_restore($rd)]]);
  return;
 }
@@ -313,7 +307,7 @@ sub trade_request
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
  return;
 }
@@ -333,7 +327,7 @@ sub trade_query
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -343,7 +337,7 @@ sub trade_cancel
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -353,7 +347,7 @@ sub transfer_trade_request
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
  return;
 }
@@ -373,7 +367,7 @@ sub transfer_trade_query
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -383,7 +377,7 @@ sub transfer_trade_cancel
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -393,7 +387,7 @@ sub transfer_restore_request
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
  return;
 }
@@ -413,7 +407,7 @@ sub transfer_restore_query
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
@@ -423,7 +417,7 @@ sub transfer_restore_cancel
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ my $eid=$mes->command_extension_register('dnslu', 'ext');
  $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
  return;
 }
