@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .MOBI Domain EPP extension commands
 ##
-## Copyright (c) 2006-2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,7 +79,7 @@ sub register_commands
 sub add_maintainer_url
 {
  my ($mes,$tag,$d)=@_;
- my $eid=$mes->command_extension_register($tag,sprintf('xmlns:mobi="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('mobi')));
+ my $eid=$mes->command_extension_register('mobi', $tag);
  $mes->command_extension($eid,$d);
  return;
 }
@@ -91,7 +91,7 @@ sub create
 
  my $d=Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl::create('mobi',$rd);
  return unless defined $d;
- add_maintainer_url($mes,'mobi:create',$d);
+ add_maintainer_url($mes,'create',$d);
  return;
 }
 
@@ -102,7 +102,7 @@ sub update
 
  my $d=Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl::update('mobi',$todo);
  return unless defined $d;
- add_maintainer_url($mes,'mobi:update',$d);
+ add_maintainer_url($mes,'update',$d);
  return;
 }
 
