@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .PL Contact EPP extension commands
 ##
-## Copyright (c) 2006,2008,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2011,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -16,6 +16,7 @@ package Net::DRI::Protocol::EPP::Extensions::PL::Contact;
 
 use strict;
 use warnings;
+use feature 'state';
 
 use Net::DRI::Util;
 
@@ -47,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2011,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,34 +65,29 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=( 
-          create => [ \&create, undef ],
-          info   => [ \&info, \&info_parse ],
-          update => [ \&update, undef ],
-         );
+ state $cmds = { 'contact' => { create => [ \&create, undef ],
+                                info   => [ \&info, \&info_parse ],
+                                update => [ \&update, undef ],
+                              }
+               };
 
- return { 'contact' => \%tmp };
+ return $cmds;
 }
 
 ####################################################################################################
 
-sub build_command_extension
-{
- my ($mes,$epp,$tag)=@_;
- return $mes->command_extension_register($tag,sprintf('xmlns:extcon="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('pl_contact')));
-}
-
 sub add_individual_and_consent
 {
  my ($epp,$contact,$op)=@_;
- my $mes=$epp->message();
 
  ## validate() has already been called
  my $ind=$contact->individual();
  my $cfp=$contact->consent_for_publishing();
 
  return unless (defined($ind) || defined($cfp));
- my $eid=build_command_extension($mes,$epp,'extcon:'.$op);
+
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('extcon', $op);
  my @e;
  push @e,['extcon:individual',$ind]           if defined($ind);
  push @e,['extcon:consentForPublishing',$cfp] if defined($cfp);
@@ -121,7 +117,7 @@ sub info
 
  return unless (Net::DRI::Util::has_auth($ep) && exists $ep->{auth}->{pw});
 
- my $eid=build_command_extension($mes,$epp,'extcon:info');
+ my $eid=$mes->command_extension_register('extcon', 'info');
  if (Net::DRI::Util::has_key($ep->{auth},'roid'))
  {
   $mes->command_extension($eid,[['extcon:authInfo',['extcon:pw',{roid=>$ep->{auth}->{roid}},$ep->{auth}->{pw}]]]);
@@ -137,7 +133,7 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('pl_contact','infData');
+ my $infdata=$mes->get_extension('extcon','infData');
  return unless defined $infdata;
 
  my $contact=$rinfo->{contact}->{$oname}->{self};
