@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Reseller Extension Mapping for EPP
 ##
-## Copyright (c) 2015,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -42,7 +42,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'reseller' => [ 'urn:ietf:params:xml:ns:reseller-1.0','reseller-1.0.xsd' ] });
+ $po->ns({ 'reseller' => 'urn:ietf:params:xml:ns:reseller-1.0' });
  return;
 }
 
@@ -73,7 +73,7 @@ sub _add_id
   push @r,['reseller:id',$id];
  }
 
- $mes->command([$command,'reseller:'.$command,sprintf('xmlns:reseller="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('reseller'))]);
+ $mes->command([$command,'reseller:'.$command, $mes->nsattrs('reseller')]);
 
  return @r;
 }
@@ -384,7 +384,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
