@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SIDN (.NL) EPP extensions
 ##
-## Copyright (c) 2009-2012,2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009-2012,2014,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -27,7 +27,7 @@ use Net::DRI::Data::Contact::SIDN;
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({sidn=>['http://rxsd.domain-registry.nl/sidn-ext-epp-1.0','sidn-ext-epp-1.0.xsd']});
+ $self->ns({sidn => 'http://rxsd.domain-registry.nl/sidn-ext-epp-1.0'});
  $self->capabilities('domain_update','status',undef); ## No changes in status possible
  $self->capabilities('contact_update','status',undef);
  $self->capabilities('contact_update','disclose',undef);
@@ -74,7 +74,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009-2012,2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009-2012,2014,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
