@@ -1,7 +1,7 @@
 ## Domain Registry Interface, VeriSign EPP Client Object Attribute Extension
 ## From epp-client-object-attribute.pdf
 ##
-## Copyright (c) 2011-2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2011-2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -36,7 +36,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'coa' => [ 'urn:ietf:params:xml:ns:coa-1.0','coa-1.0.xsd' ] });
+ $po->ns({ 'coa' => 'urn:ietf:params:xml:ns:coa-1.0' });
  return;
 }
 
@@ -173,7 +173,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2011-2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
