@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Sync aka ConsoliDate (draft-hollenbeck-epp-sync-01)
 ##
-## Copyright (c) 2006,2007,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,7 +74,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- state $rns = { 'sync' => [ 'http://www.verisign.com/epp/sync-1.0', 'sync-1.0.xsd' ] };
+ state $rns = { 'sync' => 'http://www.verisign.com/epp/sync-1.0' };
  $po->ns($rns);
  return;
 }
