@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Verification Code Extension Mapping for EPP
 ##
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -27,6 +27,10 @@ sub register_commands
  my ($class,$version)=@_;
  state $ractions = { 'info'   => [ \&info_build, \&info_parse ],
                      'create' => [ \&create_build, undef ],
+                     'delete' => [ \&create_build, undef ],
+                     'renew'  => [ \&create_build, undef ],
+                     'transfer_request' => [ \&create_build, undef ],
+                     'update' => [ \&create_build, undef ],
                    };
  state $rcmds = { 'domain'  => $ractions,
                   'contact' => $ractions,
@@ -43,7 +47,7 @@ sub setup
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/html/draft-ietf-regext-verificationcode-03'; }
+sub implements { return 'https://tools.ietf.org/html/draft-ietf-regext-verificationcode-06'; }
 
 ####################################################################################################
 
@@ -158,7 +162,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::VerificationCode - EPP Verification Code Extension mapping (draft-ietf-regext-verificationcode-03) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::VerificationCode - EPP Verification Code Extension mapping (draft-ietf-regext-verificationcode-06) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -182,7 +186,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
