@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Session commands
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -15,6 +15,8 @@
 package Net::DRI::Protocol::RRP::Core::Session;
 
 use strict;
+use warnings;
+
 use Net::DRI::Exception;
 
 =pod
@@ -45,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -78,6 +80,7 @@ sub describe
  my $mes=$rrp->message();
  $mes->command('describe');
  $mes->options('Target',$what) if $what;
+ return;
 }
 
 sub describe_parse
@@ -87,6 +90,7 @@ sub describe_parse
  return unless $mes->is_success();
 
  $rinfo->{session}->{describe}->{protocol}=$mes->entities('protocol');
+ return;
 }
 
 sub quit
@@ -94,6 +98,7 @@ sub quit
  my ($rrp)=@_;
  my $mes=$rrp->message();
  $mes->command('quit');
+ return;
 }
 
 sub session
@@ -106,6 +111,7 @@ sub session
  $mes->options('Id',$id);
  $mes->options('Password',$pass);
  $mes->options('NewPassword',$newpass) if (defined($newpass) && $newpass && ($newpass ne $pass));
+ return;
 }
 
 ###############################################################################################
