@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SMTP Transport
 ##
-## Copyright (c) 2006,2007,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -52,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -92,10 +92,10 @@ sub new
 
 sub end { }
 
-sub send
+sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($self,$ctx,$tosend)=@_;
- $self->SUPER::send($ctx,$tosend,\&_send,undef);
+ return $self->SUPER::send($ctx,$tosend,\&_send,undef);
 }
 
 sub _send
@@ -121,6 +121,7 @@ sub _send
 sub receive
 {
  my ($self,$ctx,$count)=@_;
+ return;
 }
 
 ####################################################################################################
