@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SOAP Transport (HTTP/HTTPS)
 ##
-## Copyright (c) 2005,2009-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2009-2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -88,7 +88,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2009-2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2009-2011,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -145,7 +145,8 @@ sub new
 
  if (exists($opts{ssl_ca_file}) && (-s $opts{ssl_ca_file}))
  {
-  $ENV{HTTPS_CA_FILE}=$opts{ssl_ca_file}; ## How to handle multiple SOAP instances in the same process ??
+  ## How to handle multiple SOAP instances in the same process ??
+  $ENV{HTTPS_CA_FILE}=$opts{ssl_ca_file}; ## no critic (Variables::RequireLocalizedPunctuationVars)
  }
 
  $t{soap}=$service;
@@ -153,17 +154,17 @@ sub new
  return $self;
 }
 
-sub soap_fault
+sub soap_fault ## no critic (Subroutines::RequireFinalReturn)
 {
  my($soap,$res)=@_; 
  my $msg=ref $res ? $res->faultstring() : $soap->transport()->status();
  Net::DRI::Exception->die(1,'transport/soap',7,'SOAP fault: '.$msg);
 }
 
-sub send
+sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($self,$ctx,$tosend)=@_;
- $self->SUPER::send($ctx,$tosend,\&_soap_send,sub {});
+ return $self->SUPER::send($ctx,$tosend,\&_soap_send,sub {});
 }
 
 sub _soap_send
