@@ -36,10 +36,17 @@ sub new_epp
 
 sub dri { return $_[0]->{dri}; }
 
+sub set_result
+{
+ my ($self, $code, $message) = @_;
+ $self->{_result} = r($code, $message);
+}
+
 sub set_response
 {
  my ($self, $response) = @_;
- ${$self->{output}} = $E1.'<response>'.r().($response // '').$TRID.'</response>'.$E2;
+ ${$self->{output}} = $response=~m/^\s*<\?xml/ ? $response : $E1.'<response>'.($self->{_result} // r()).($response // '').$TRID.'</response>'.$E2;
+ delete $self->{_result};
 }
 
 sub get_command
